==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/fr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Saved" : "Sauvegardé",
    "Saving failed:" : "L'enregistrement a échoué:",
    "File MIME type" : "Type MIME du fichier",
    "is" : "est",
    "is not" : "n'est pas",
    "matches" : "correspond",
    "does not match" : "ne correspond pas",
    "Example: {placeholder}" : "Exemple: {placeholder}",
    "File size (upload)" : "Taille du fichier ( à télécharger )",
    "less" : "moins",
    "less or equals" : "inférieur ou égal",
    "greater or equals" : "supérieur ou égal",
    "greater" : "plus grand que",
    "File system tag" : "Étiquette collaborative du fichier",
    "is tagged with" : "est étiqueté avec",
    "is not tagged with" : "n'est pas étiqueté avec",
    "Select tag…" : "Sélectionner une étiquette...",
    "Request remote address" : "Demander une adresse distante",
    "matches IPv4" : "correspond à une adresse IPv4",
    "does not match IPv4" : "ne correspond pas à une adresse IPv4",
    "matches IPv6" : "correspond à une adresse IPv6",
    "does not match IPv6" : "ne correspond pas à une adresse IPv6",
    "Request time" : "Temps de requête",
    "between" : "entre",
    "not between" : "en dehors de",
    "Start" : "Démarrer",
    "End" : "Fin",
    "Select timezone…" : "Sélectionner le fuseau horaire...",
    "Request URL" : "Demande d'URL",
    "Predefined URLs" : "URL prédéfinis",
    "Files WebDAV" : "Fichiers WebDAV",
    "Request user agent" : "Agent utilisateur requis",
    "Sync clients" : "Clients de synchronisation",
    "Android client" : "Client Android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client de bureau",
    "User group membership" : "Membre du groupe d'utilisateur",
    "is member of" : "est membre de",
    "is not member of" : "n'est pas membre de",
    "The given operator is invalid" : "L'opérateur donné est invalide",
    "The given regular expression is invalid" : "L'expression régulière donnée est invalide",
    "The given file size is invalid" : "La taille du fichier donné est invalide",
    "The given tag id is invalid" : "L’identifiant de l'étiquette donné est invalide",
    "The given IP range is invalid" : "La plage d'adresse IP donnée est invalide",
    "The given IP range is not valid for IPv4" : "La plage d'adresse IP donnée n'est pas valide pour l'IPv4",
    "The given IP range is not valid for IPv6" : "La plage d'adresse IP donnée n'est pas valide pour l'IPv6",
    "The given time span is invalid" : "La durée est invalide",
    "The given start time is invalid" : "La date de début est invalide",
    "The given end time is invalid" : "La date de fin est invalide",
    "The given group does not exist" : "Le groupe donné n'existe pas",
    "Check %s is invalid or does not exist" : "Vérifiez si %s est invalide ou n'existe pas",
    "Operation #%s does not exist" : "L'opération #%s n'existe pas",
    "Operation %s does not exist" : "L'opération %s n'existe pas",
    "Operation %s is invalid" : "L'opération %s est invalide",
    "Check %s does not exist" : "Vérifiez si %s n'existe pas",
    "Check %s is invalid" : "Vérifiez si %s est invalide",
    "Check #%s does not exist" : "Vérifiez si #%s n'existe pas",
    "Workflow" : "Flux d'activités",
    "Files workflow engine" : "Moteur du flux de travail des fichiers",
    "Open documentation" : "Voir la documentation",
    "Add rule group" : "Ajouter une règle de groupe",
    "Short rule description" : "Trier par description de règle",
    "Add rule" : "Ajouter règle",
    "Reset" : "Réinitialiser",
    "Save" : "Enregistrer",
    "Saving…" : "Enregistrement...",
    "Loading…" : "Chargement...",
    "Successfully saved" : "Enregistré avec succès",
    "File mime type" : "Type MIME du fichier"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/fr.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "L'opérateur donné est invalide",
    "The given regular expression is invalid" : "L'expression régulière donnée est invalide",
    "The given file size is invalid" : "La taille du fichier donné est invalide",
    "The given tag id is invalid" : "L’identifiant de l'étiquette donné est invalide",
    "The given IP range is invalid" : "La plage d'adresse IP donnée est invalide",
    "The given IP range is not valid for IPv4" : "La plage d'adresse IP donnée n'est pas valide pour l'IPv4",
    "The given IP range is not valid for IPv6" : "La plage d'adresse IP donnée n'est pas valide pour l'IPv6",
    "The given time span is invalid" : "La durée est invalide",
    "The given start time is invalid" : "La date de début est invalide",
    "The given end time is invalid" : "La date de fin est invalide",
    "The given group does not exist" : "Le groupe donné n'existe pas",
    "File" : "Fichier",
    "File created" : "Fichier créé",
    "File updated" : "Fichier mis à jour",
    "File renamed" : "Fichier renommé",
    "File deleted" : "Fichier supprimé",
    "File copied" : "Fichier copié",
    "Tag assigned" : "Étiquette assignée",
    "Operation #%s does not exist" : "L'opération #%s n'existe pas",
    "No events are chosen." : "Aucun évènement a été choisi.",
    "Operation %s does not exist" : "L'opération %s n'existe pas",
    "Operation %s is invalid" : "L'opération %s est invalide",
    "Check %s does not exist" : "Vérifiez si %s n'existe pas",
    "Check %s is invalid" : "Vérifiez si %s est invalide",
    "Check #%s does not exist" : "Vérifiez si #%s n'existe pas",
    "Check %s is invalid or does not exist" : "Vérifiez si %s est invalide ou n'existe pas",
    "Workflows" : "Workflows",
    "Nextcloud workflow engine" : "Moteur de workflow Nextcloud",
    "Select a filter" : "Sélectionner un filtre",
    "Select a file type" : "Sélectionnez un type de fichier",
    "Images" : "Images",
    "Office documents" : "Documents Office",
    "PDF documents" : "Documents PDF",
    "No results" : "Aucun résultat",
    "%s (invisible)" : "%s (invisible)",
    "%s (restricted)" : "%s (restreint)",
    "Predefined URLs" : "URL prédéfinis",
    "Files WebDAV" : "Fichiers WebDAV",
    "Others" : "Autres",
    "Custom URL" : "URL personnalisée",
    "Android client" : "Client Android",
    "iOS client" : "Client iOS",
    "Desktop client" : "Client de bureau",
    "Thunderbird & Outlook addons" : "Modules complémentaires Thunderbird & Outlook",
    "When" : "Quand",
    "and" : "et",
    "Cancel" : "Annuler",
    "Delete" : "Supprimer",
    "The configuration is invalid" : "Configuration non valide",
    "Show less" : "Afficher moins",
    "Show more" : "Afficher plus",
    "File name" : "Nom du fichier",
    "is" : "est",
    "is not" : "n'est pas",
    "matches" : "correspond",
    "does not match" : "ne correspond pas",
    "File MIME type" : "Type MIME du fichier",
    "File size (upload)" : "Taille du fichier ( à télécharger )",
    "less" : "moins",
    "less or equals" : "inférieur ou égal",
    "greater or equals" : "supérieur ou égal",
    "greater" : "plus grand que",
    "Request remote address" : "Demander une adresse distante",
    "matches IPv4" : "correspond à une adresse IPv4",
    "does not match IPv4" : "ne correspond pas à une adresse IPv4",
    "matches IPv6" : "correspond à une adresse IPv6",
    "does not match IPv6" : "ne correspond pas à une adresse IPv6",
    "File system tag" : "Étiquette collaborative du fichier",
    "is tagged with" : "est étiqueté avec",
    "is not tagged with" : "n'est pas étiqueté avec",
    "Request URL" : "Demande d'URL",
    "Request time" : "Temps de requête",
    "between" : "entre",
    "not between" : "en dehors de",
    "Request user agent" : "Agent utilisateur requis",
    "User group membership" : "Membre du groupe d'utilisateur",
    "is member of" : "est membre de",
    "is not member of" : "n'est pas membre de",
    "Short rule description" : "Trier par description de règle",
    "Add rule" : "Ajouter règle",
    "Reset" : "Réinitialiser",
    "Save" : "Enregistrer",
    "Saving…" : "Enregistrement...",
    "Group list is empty" : "La liste du groupe est vide",
    "Unable to retrieve the group list" : "Impossible de récupérer la liste du groupe",
    "Saved" : "Sauvegardé",
    "Saving failed:" : "L'enregistrement a échoué:",
    "Add rule group" : "Ajouter une règle de groupe",
    "Example: {placeholder}" : "Exemple: {placeholder}",
    "Select tag…" : "Sélectionner une étiquette...",
    "Start" : "Démarrer",
    "End" : "Fin",
    "Select timezone…" : "Sélectionner le fuseau horaire...",
    "Sync clients" : "Clients de synchronisation",
    "Workflow" : "Flux d'activités",
    "Files workflow engine" : "Moteur de Workflow de fichiers",
    "Open documentation" : "Voir la documentation",
    "Loading…" : "Chargement...",
    "Tag management" : "Gestion des étiquettes"
},
"nplurals=2; plural=(n > 1);");
